@@ -121,10 +121,10 @@ class tree_set:
             try:
                 self.distance_matrix = pd.read_csv(
                     self.distance_matrix,
-                    header=0,
-                    index_col=0,
-                    dtype=np.float32,
                 ).values
+                #    header=0,
+                #    index_col=0,
+                #    dtype=np.float32,
                 # self.distance_matrix.columns = list(range(self.distance_matrix.shape[1]))
             except:
                 sys.exit(
@@ -287,6 +287,8 @@ class tree_set:
         Returns:
             plot: either interactive or not
         """
+
+        # you can surely write something better here @andrear
         if type(plot_set) == type(None):
             plot_set = self.sets
         if method == "pca":
@@ -582,7 +584,7 @@ class set_collection(tree_set):
         self.id = uuid.uuid4()
         self.file = file + str(self.id)
         self.distance_matrix = (
-            pd.read_csv(distance_matrix, header=None).values
+            pd.read_csv(distance_matrix, header=None, index_col=None).values  #
             if distance_matrix
             else distance_matrix
         )
@@ -691,7 +693,6 @@ class set_collection(tree_set):
             )
 
         if method in ("hashrf", "hashrf_weighted", "quartet", "triplet"):
-            hashrf.bash_command("echo QUI")
             hashrf.bash_command(f"rm {self.file}")
 
         print(f"[bold blue]{method} | Done!")
